summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger/variablewidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'languages/cpp/debugger/variablewidget.cpp')
-rw-r--r--languages/cpp/debugger/variablewidget.cpp78
1 files changed, 39 insertions, 39 deletions
diff --git a/languages/cpp/debugger/variablewidget.cpp b/languages/cpp/debugger/variablewidget.cpp
index 2b9e4de3..581b3cb8 100644
--- a/languages/cpp/debugger/variablewidget.cpp
+++ b/languages/cpp/debugger/variablewidget.cpp
@@ -77,8 +77,8 @@ namespace GDBDebugger
VariableWidget::VariableWidget(GDBController* controller,
GDBBreakpointWidget* breakpointWidget,
- TQWidget *tqparent, const char *name)
-: TQWidget(tqparent, name)
+ TQWidget *parent, const char *name)
+: TQWidget(parent, name)
{
setIcon(SmallIcon("math_brace"));
setCaption(i18n("Variable Tree"));
@@ -197,11 +197,11 @@ void VariableWidget::focusInEvent(TQFocusEvent */*e*/)
// **************************************************************************
// **************************************************************************
-VariableTree::VariableTree(VariableWidget *tqparent,
+VariableTree::VariableTree(VariableWidget *parent,
GDBController* controller,
GDBBreakpointWidget* breakpointWidget,
const char *name)
- : KListView(tqparent, name),
+ : KListView(parent, name),
TQToolTip( viewport() ),
controller_(controller),
breakpointWidget_(breakpointWidget),
@@ -244,7 +244,7 @@ void VariableTree::slotContextMenu(KListView *, TQListViewItem *item)
setSelected(item, true); // Need to select this item.
- if (item->tqparent())
+ if (item->parent())
{
KPopupMenu popup(this);
KPopupMenu format(this);
@@ -360,7 +360,7 @@ void VariableTree::slotContextMenu(KListView *, TQListViewItem *item)
{
if (VarItem *item = dynamic_cast<VarItem*>(currentItem()))
{
- ((VariableWidget*)tqparent())->
+ ((VariableWidget*)parent())->
slotEvaluateExpression(item->gdbExpression());
}
}
@@ -368,7 +368,7 @@ void VariableTree::slotContextMenu(KListView *, TQListViewItem *item)
{
if (VarItem *item = dynamic_cast<VarItem*>(currentItem()))
{
- ((VariableWidget*)tqparent())->
+ ((VariableWidget*)parent())->
slotAddWatchVariable(item->gdbExpression());
}
}
@@ -547,8 +547,8 @@ void VariableTree::slotEvaluateExpression(const TQString &expression)
TQListViewItem *VariableTree::findRoot(TQListViewItem *item) const
{
- while (item->tqparent())
- item = item->tqparent();
+ while (item->parent())
+ item = item->parent();
return item;
}
@@ -1018,15 +1018,15 @@ void VariableTree::handleAddressComputed(const GDBMI::ResultRecord& r)
// **************************************************************************
// **************************************************************************
-TrimmableItem::TrimmableItem(VariableTree *tqparent)
- : KListViewItem (tqparent, tqparent->lastChild())
+TrimmableItem::TrimmableItem(VariableTree *parent)
+ : KListViewItem (parent, parent->lastChild())
{
}
// **************************************************************************
-TrimmableItem::TrimmableItem(TrimmableItem *tqparent)
- : KListViewItem (tqparent, tqparent->lastChild())
+TrimmableItem::TrimmableItem(TrimmableItem *parent)
+ : KListViewItem (parent, parent->lastChild())
{
}
@@ -1044,7 +1044,7 @@ void TrimmableItem::paintCell(TQPainter *p, const TQColorGroup &cg,
if ( !p )
return;
// make toplevel item (watch and frame items) names bold
- if (column == 0 && !tqparent())
+ if (column == 0 && !parent())
{
TQFont f = p->font();
f.setBold(true);
@@ -1069,10 +1069,10 @@ TQListViewItem *TrimmableItem::lastChild() const
int VarItem::varobjIndex = 0;
-VarItem::VarItem(TrimmableItem *tqparent,
+VarItem::VarItem(TrimmableItem *parent,
const TQString& expression,
bool frozen)
- : TrimmableItem (tqparent),
+ : TrimmableItem (parent),
expression_(expression),
highlight_(false),
oldSpecialRepresentationSet_(false),
@@ -1116,9 +1116,9 @@ VarItem::VarItem(TrimmableItem *tqparent,
createVarobj();
}
-VarItem::VarItem(TrimmableItem *tqparent, const GDBMI::Value& varobj,
+VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
format_t format, bool baseClassMember)
-: TrimmableItem (tqparent),
+: TrimmableItem (parent),
highlight_(false),
oldSpecialRepresentationSet_(false),
format_(format),
@@ -1394,7 +1394,7 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
{
kdDebug(9012) << "Creating new varobj "
<< exp << " " << baseObject << "\n";
// Propagate format from tqparent.
VarItem* v = 0;
v = new VarItem(this, tqchildren[i], format_, baseObject);
}
@@ -1469,10 +1469,10 @@ TQString VarItem::displayName() const
if (expression_[0] != '*')
return expression_;
- if (const VarItem* tqparent =
- dynamic_cast<const VarItem*>(TrimmableItem::tqparent()))
+ if (const VarItem* parent =
+ dynamic_cast<const VarItem*>(TrimmableItem::parent()))
{
- return "*" + tqparent->displayName();
+ return "*" + parent->displayName();
}
else
{
@@ -1504,24 +1504,24 @@ TQString VarItem::gdbExpression() const
// - number, for array element
// - identifier, for member,
// - ***intentifier, for derefenreced pointer.
- const VarItem* tqparent = dynamic_cast<const VarItem*>(TrimmableItem::tqparent());
+ const VarItem* parent = dynamic_cast<const VarItem*>(TrimmableItem::parent());
bool ok = false;
expression_.toInt(&ok);
if (ok)
{
- // Array, tqparent always exists.
- return tqparent->gdbExpression() + "[" + expression_ + "]";
+ // Array, parent always exists.
+ return parent->gdbExpression() + "[" + expression_ + "]";
}
else if (expression_[0] == '*')
{
- if (tqparent)
+ if (parent)
{
// For MI, expression_ can be "*0" (meaing
// references 0-th element of some array).
// So, we really need to get to the tqparent to computed the right
// gdb expression.
- return "*" + tqparent->gdbExpression();
+ return "*" + parent->gdbExpression();
}
else
{
@@ -1532,14 +1532,14 @@ TQString VarItem::gdbExpression() const
}
else
{
- if (tqparent)
+ if (parent)
/* This is varitem corresponds to a base suboject,
- the expression should cast tqparent to the base's
+ the expression should cast parent to the base's
type. */
if (baseClassMember_)
- return "((" + expression_ + ")" + tqparent->gdbExpression() + ")";
+ return "((" + expression_ + ")" + parent->gdbExpression() + ")";
else
- return tqparent->gdbExpression() + "." + expression_;
+ return parent->gdbExpression() + "." + expression_;
else
return expression_;
}
@@ -1877,7 +1877,7 @@ VariableTree* VarItem::varTree() const
void VarItem::unhookFromGdb()
{
// Unhook tqchildren first, so that child varitems are deleted
// before tqparent. Strictly speaking, we can avoid calling
// -var-delete on child varitems, but that's a bit cheesy,
for(TQListViewItem* child = firstChild();
child; child = child->nextSibling())
@@ -1931,8 +1931,8 @@ bool VarItem::isAlive() const
// **************************************************************************
// **************************************************************************
-VarFrameRoot::VarFrameRoot(VariableTree *tqparent, int frameNo, int threadNo)
- : TrimmableItem (tqparent),
+VarFrameRoot::VarFrameRoot(VariableTree *parent, int frameNo, int threadNo)
+ : TrimmableItem (parent),
needLocals_(false),
frameNo_(frameNo),
threadNo_(threadNo),
@@ -1956,8 +1956,8 @@ void VarFrameRoot::setOpen(bool open)
if (frameOpened && needLocals_)
{
needLocals_ = false;
- VariableTree* tqparent = static_cast<VariableTree*>(listView());
- tqparent->updateCurrentFrame();
+ VariableTree* parent = static_cast<VariableTree*>(listView());
+ parent->updateCurrentFrame();
}
}
@@ -1978,8 +1978,8 @@ void VarFrameRoot::setDirty()
// **************************************************************************
// **************************************************************************
-WatchRoot::WatchRoot(VariableTree *tqparent)
- : TrimmableItem(tqparent)
+WatchRoot::WatchRoot(VariableTree *parent)
+ : TrimmableItem(parent)
{
setText(0, i18n("Watch"));
setOpen(true);
@@ -1394,7 +1394,7 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
kdDebug(9012) << "Creating new varobj "
<< exp << " " << baseObject << "\n";
- // Propagate format from tqparent.
+ // Propagate format from parent.
VarItem* v = 0;
v = new VarItem(this, tqchildren[i], format_, baseObject);
@@ -1504,24 +1504,24 @@ TQString VarItem::gdbExpression() const
// For MI, expression_ can be "*0" (meaing
// references 0-th element of some array).
- // So, we really need to get to the tqparent to computed the right
+ // So, we really need to get to the parent to computed the right
// gdb expression.
@@ -1877,7 +1877,7 @@ VariableTree* VarItem::varTree() const
{
// Unhook tqchildren first, so that child varitems are deleted
- // before tqparent. Strictly speaking, we can avoid calling
+ // before parent. Strictly speaking, we can avoid calling
// -var-delete on child varitems, but that's a bit cheesy,
for(TQListViewItem* child = firstChild();